Installation
============

You can install from PyPi:

.. code:: bash

    pip install mbrs

For developers, it can be installed from the source.

.. code:: bash

    git clone https://github.com/naist-nlp/mbrs.git
    cd mbrs/
    pip install ./
